@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # Copyright (c) 2013, AT&T Labs, Yun Mao <yunmao@gmail.com>
 # All Rights Reserved.
 #
@@ -16,13 +16,13 @@
 
 """pylint error checking."""
 
+from io import StringIO
 import json
 import re
 import sys
 
 from pylint import lint
 from pylint.reporters import text
-from six.moves import cStringIO as StringIO
 
 ignore_codes = [
     # Note(maoy): E1103 is error code related to partial type inference
